summaryrefslogtreecommitdiffstats
path: root/content/browser/browsing_instance.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/browser/browsing_instance.h')
-rw-r--r--content/browser/browsing_instance.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/content/browser/browsing_instance.h b/content/browser/browsing_instance.h
index d3baf8a..f32b3d5 100644
--- a/content/browser/browsing_instance.h
+++ b/content/browser/browsing_instance.h
@@ -12,10 +12,11 @@
#include "content/common/content_export.h"
class GURL;
-class SiteInstance;
+class SiteInstanceImpl;
namespace content {
class BrowserContext;
+class SiteInstance;
}
///////////////////////////////////////////////////////////////////////////////
@@ -80,19 +81,20 @@ class CONTENT_EXPORT BrowsingInstance
// Get the SiteInstance responsible for rendering the given URL. Should
// create a new one if necessary, but should not create more than one
// SiteInstance per site.
- SiteInstance* GetSiteInstanceForURL(const GURL& url);
+ content::SiteInstance* GetSiteInstanceForURL(const GURL& url);
// Adds the given SiteInstance to our map, to ensure that we do not create
// another SiteInstance for the same site.
- void RegisterSiteInstance(SiteInstance* site_instance);
+ void RegisterSiteInstance(content::SiteInstance* site_instance);
// Removes the given SiteInstance from our map, after all references to it
// have been deleted. This means it is safe to create a new SiteInstance
// if the user later visits a page from this site, within this
// BrowsingInstance.
- void UnregisterSiteInstance(SiteInstance* site_instance);
+ void UnregisterSiteInstance(content::SiteInstance* site_instance);
- friend class SiteInstance;
+ friend class SiteInstanceImpl;
+ friend class content::SiteInstance;
friend class base::RefCounted<BrowsingInstance>;
@@ -101,7 +103,7 @@ class CONTENT_EXPORT BrowsingInstance
private:
// Map of site to SiteInstance, to ensure we only have one SiteInstance per
- typedef base::hash_map<std::string, SiteInstance*> SiteInstanceMap;
+ typedef base::hash_map<std::string, content::SiteInstance*> SiteInstanceMap;
// Map of BrowserContext to SiteInstanceMap, for use in the process-per-site
// model.
@@ -120,7 +122,7 @@ class CONTENT_EXPORT BrowsingInstance
// Utility routine which removes the passed SiteInstance from the passed
// SiteInstanceMap.
bool RemoveSiteInstanceFromMap(SiteInstanceMap* map, const std::string& site,
- SiteInstance* site_instance);
+ content::SiteInstance* site_instance);
// Common browser context to which all SiteInstances in this BrowsingInstance
// must belong.
@@ -128,7 +130,7 @@ class CONTENT_EXPORT BrowsingInstance
// Map of site to SiteInstance, to ensure we only have one SiteInstance per
// site. The site string should be the possibly_invalid_spec() of a GURL
// obtained with SiteInstance::GetSiteForURL. Note that this map may not
// contain every active SiteInstance, because a race exists where two
// SiteInstances can be assigned to the same site. This is ok in rare cases.
// This field is only used if we are not using process-per-site.
@@ -128,7 +130,7 @@ class CONTENT_EXPORT BrowsingInstance
// Map of site to SiteInstance, to ensure we only have one SiteInstance per
// site. The site string should be the possibly_invalid_spec() of a GURL
- // obtained with SiteInstance::GetSiteForURL. Note that this map may not
+ // obtained with SiteInstanceImpl::GetSiteForURL. Note that this map may not
// contain every active SiteInstance, because a race exists where two
// SiteInstances can be assigned to the same site. This is ok in rare cases.